@@ -34,10 +34,6 @@
 
 #include <sys/wait.h>
 
-#if defined mx_HAVE_CLOSE_RANGE
-# include mx_CLOSE_RANGE_H
-#endif
-
 #include <su/cs.h>
 #include <su/mem.h>
 
@@ -503,12 +499,6 @@ mx_child_in_child_setup(struct mx_child_ctx *ccp){
          ) == mx_CHILD_SPAWN_CONTROL)
       close(S(int,ccp->cc__cpipe[1]));
 
-#if defined mx_HAVE_CLOSE_RANGE
-   mx_CLOSE_RANGE_FUN(STDERR_FILENO + 1, ~0u);
-#elif defined mx_HAVE_CLOSEFROM
-   closefrom(STDERR_FILENO + 1);
-#endif
-
    if(ccp->cc_mask != NIL){
       sigset_t *ssp;
 
